==> enchant-2.1.3.tar.gz: enchant-2.1.3/tests/provider/enchant_provider_broker_set_error_tests.cpp <==
/* Copyright (c) 2007 Eric Scott Albright
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <UnitTest++.h>
#include <enchant-provider.h>

#include "EnchantBrokerTestFixture.h"

struct EnchantBrokerSetErrorTests : EnchantBrokerTestFixture
{
  //Setup
    EnchantBrokerSetErrorTests()
  {
      provider = GetMockProvider();
  }

  std::string GetErrorMessage(){
      const char* error = enchant_broker_get_error(_broker);
      if(error == NULL){
          return std::string();
      }
      return std::string(error);
  }

  EnchantProvider* provider;
};

/**
 * enchant_provider_set_error
 * @provider: A non-null provider
 * @err: A non-null error message
 * 
 * Sets the current runtime error to @err. This API is private to
 * the providers.
 */

/////////////////////////////////////////////////////////////////////////////
// Test Normal Operation

TEST_FIXTURE(EnchantBrokerSetErrorTests, 
             SetErrorMessageOnProvider)
{
    std::string expectedErrorMessage("Error message to display");
    enchant_provider_set_error(provider, expectedErrorMessage.c_str());

    CHECK_EQUAL(expectedErrorMessage, GetErrorMessage());
}

/////////////////////////////////////////////////////////////////////////////
// Test Error Conditions
TEST_FIXTURE(EnchantBrokerSetErrorTests, 
             SetErrorMessageOnProvider_NullProvider_NoErrorSet)
{
    enchant_provider_set_error(NULL, "Error message to display");

    CHECK_EQUAL(std::string(), GetErrorMessage());
}

TEST_FIXTURE(EnchantBrokerSetErrorTests, 
             SetErrorMessageOnProvider_NullError_NoErrorSet)
{
    enchant_provider_set_error(provider, NULL);

    CHECK_EQUAL(std::string(), GetErrorMessage());
}

TEST_FIXTURE(EnchantBrokerSetErrorTests,
             SetErrorMessageOnProvider_InvalidUtf8ErrorMessage_NoErrorSet)
{
    enchant_provider_set_error(provider, "\xa5\xf1\x08");

    CHECK_EQUAL(std::string(), GetErrorMessage());
}

TEST_FIXTURE(EnchantBrokerSetErrorTests, 
             SetErrorMessageOnProvider_MessageCopied)
{
    std::string expectedErrorMessage("Error message to display");
    enchant_provider_set_error(provider, expectedErrorMessage.c_str());

    expectedErrorMessage[0] = 'e';
    CHECK(expectedErrorMessage != GetErrorMessage());
}

==> enchant-2.7.2.tar.gz: enchant-2.7.2/tests/provider/enchant_provider_broker_set_error_tests.cpp <==
/* Copyright (c) 2007 Eric Scott Albright
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <UnitTest++/UnitTest++.h>
#include <enchant-provider.h>

#include "EnchantBrokerTestFixture.h"

struct EnchantBrokerSetErrorTests : EnchantBrokerTestFixture
{
  //Setup
    EnchantBrokerSetErrorTests()
  {
      provider = GetMockProvider();
  }

  std::string GetErrorMessage(){
      const char* error = enchant_broker_get_error(_broker);
      if(error == NULL){
          return std::string();
      }
      return std::string(error);
  }

  EnchantProvider* provider;
};

/**
 * enchant_provider_set_error
 * @provider: A non-null provider
 * @err: A non-null error message
 * 
 * Sets the current runtime error to @err. This API is private to
 * the providers.
 */

/////////////////////////////////////////////////////////////////////////////
// Test Normal Operation

TEST_FIXTURE(EnchantBrokerSetErrorTests, 
             SetErrorMessageOnProvider)
{
    std::string expectedErrorMessage("Error message to display");
    enchant_provider_set_error(provider, expectedErrorMessage.c_str());

    CHECK_EQUAL(expectedErrorMessage, GetErrorMessage());
}

/////////////////////////////////////////////////////////////////////////////
// Test Error Conditions
TEST_FIXTURE(EnchantBrokerSetErrorTests, 
             SetErrorMessageOnProvider_NullProvider_NoErrorSet)
{
    enchant_provider_set_error(NULL, "Error message to display");

    CHECK_EQUAL(std::string(), GetErrorMessage());
}

TEST_FIXTURE(EnchantBrokerSetErrorTests, 
             SetErrorMessageOnProvider_NullError_NoErrorSet)
{
    enchant_provider_set_error(provider, NULL);

    CHECK_EQUAL(std::string(), GetErrorMessage());
}

TEST_FIXTURE(EnchantBrokerSetErrorTests, 
             SetErrorMessageOnProvider_MessageCopied)
{
    std::string expectedErrorMessage("Error message to display");
    enchant_provider_set_error(provider, expectedErrorMessage.c_str());

    expectedErrorMessage[0] = 'e';
    CHECK(expectedErrorMessage != GetErrorMessage());
}
